# English
This Telegram client will help you to cleanse your messages in telegram, removing compromising messages so that if police stops you and check your phone they cold not find anything by typing "Ukraine" or "Putin" for example. I hope that this bunch of scripts will help you to feel safer.

Putin is a huilo. Russia will be free.

# Русский
Это приложение Телеграм которое позволит вам удобнее вычищать ваши переписки от крамолы чтобы если вас остановят менты они бы ничего не нашли по слову "Украина" или "Путин" например. Надеюсь, эта кучка скриптов поможет вам чувствовать себя безопаснее.

Путин хуйло. Россия будет свободной.